pub enum ReadyOutcome {
Ready,
Completed,
}Expand description
Outcome of waiting for readiness on a backtest session.
Variants
Ready
The session is ready to accept a Continue request.
Completed
The session completed before becoming ready.