build_programdata_bytes

Function build_programdata_bytes 

pub fn build_programdata_bytes(
    elf: &[u8],
    deploy_slot: u64,
    upgrade_authority: Option<&Address>,
) -> Vec<u8> 
Serialize ELF bytes into a ProgramData account data blob.

Exposed as a building block if you need to construct the account yourself (e.g. to set a custom lamport amount after calling rpc.get_minimum_balance_for_rent_exemption).