pub struct BacktestClient { /* private fields */ }Expand description
Backtest WebSocket client configured with a base URL and API key.
Build with BacktestClient::builder, which supports optional timeouts and
raw message logging.
Implementations
Sourceimpl BacktestClient
impl BacktestClient
Sourcepub fn builder() -> BacktestClientBuilder
pub fn builder() -> BacktestClientBuilder
Create an instance of BacktestClient using the builder syntax
Sourceimpl BacktestClient
impl BacktestClient
Sourcepub async fn create_session(
&self,
create: CreateSession,
) -> BacktestClientResult<BacktestSession>
pub async fn create_session( &self, create: CreateSession, ) -> BacktestClientResult<BacktestSession>
Create a backtest session by connecting and sending a CreateBacktestSession request.
Sourcepub async fn create_sessions(
&self,
create: CreateSession,
) -> BacktestClientResult<Vec<String>>
pub async fn create_sessions( &self, create: CreateSession, ) -> BacktestClientResult<Vec<String>>
Create one or many sessions and return the resulting session IDs.
When CreateSession.parallel is true, this may return many IDs.
Sourcepub async fn create_sessions_with_progress(
&self,
create: CreateSession,
on_session_created: impl FnMut(String) + Send,
) -> BacktestClientResult<Vec<String>>
pub async fn create_sessions_with_progress( &self, create: CreateSession, on_session_created: impl FnMut(String) + Send, ) -> BacktestClientResult<Vec<String>>
Create one or many sessions and stream each successfully created session ID.
on_session_created is called for each streamed SessionCreated response.
Sourcepub async fn attach_session(
&self,
session_id: impl Into<String>,
last_sequence: Option<u64>,
) -> BacktestClientResult<BacktestSession>
pub async fn attach_session( &self, session_id: impl Into<String>, last_sequence: Option<u64>, ) -> BacktestClientResult<BacktestSession>
Attach to an existing backtest session over the control websocket.