Continue

Struct Continue 

pub struct Continue {
    pub advance_count: u64,
    pub transactions: Vec<String>,
    pub modify_accounts: BTreeMap<Address, AccountData>,
}
Builder for Continue requests.

Use this to advance the simulation, inject transactions, or patch accounts.

Fields

advance_count: u64transactions: Vec<String>modify_accounts: BTreeMap<Address, AccountData>

Implementations

Source

impl Continue

pub fn builder() -> ContinueBuilder

Create an instance of Continue using the builder syntax

Source

impl Continue

pub fn push_transaction_base64(self, data: impl Into<String>) -> Self

Append a base64-encoded transaction payload.

pub fn push_transaction_bytes(self, bytes: &[u8]) -> Self

Append a raw transaction payload encoded as base64.

pub fn push_transaction( self, transaction: &impl SerializableTransaction, ) -> Result<Self, SerializeEncodeError>

Append a serializable transaction encoded as base64.

pub fn modify_account(self, address: Address, account: AccountData) -> Self

Modify an account state prior to execution.

pub fn into_params(self) -> ContinueParams

Convert the builder into API parameters.