Module subscriptions

Module subscriptions 

Structs

AccountDiffContext
Slot context included in every account diff notification.
AccountDiffNotification
A single account diff notification delivered by accountDiffSubscribe.
AccountDiffSubscriptionHandle
Handle for a running account diff subscription background task.
LogSubscriptionHandle
Handle for a running log subscription background task.
SubscriptionHandle
A unified subscription handle that can represent any subscription type.

Enums

SubscriptionError
Error establishing a PubSub log subscription.

Functions

subscribe_account_diffs
Subscribe to account diff notifications and invoke a callback for each one.
subscribe_program_logs
Subscribe to program log notifications and invoke a callback for each one.