pub struct AccountDiffSubscriptionHandle {
pub join_handle: JoinHandle<()>,
pub stop: Sender<bool>,
}Expand description
Handle for a running account diff subscription background task.
Send true on stop to request a clean shutdown, then await join_handle.
Fields
join_handle: JoinHandle<()>stop: Sender<bool>Trait Implementations
Sourceimpl From<AccountDiffSubscriptionHandle> for SubscriptionHandle
impl From<AccountDiffSubscriptionHandle> for SubscriptionHandle
Sourcefn from(h: AccountDiffSubscriptionHandle) -> Self
fn from(h: AccountDiffSubscriptionHandle) -> Self
Converts to this type from the input type.