filter_ranges

Function filter_ranges 

pub fn filter_ranges(
    ranges: &[AvailableRange],
    after: Option<&RangeBound>,
    before: Option<&RangeBound>,
) -> Vec<AvailableRange>
Filter ranges to only those that overlap the [after, before] window.

When a bound is a RangeBound::Time, the range’s UTC timestamp fields are used; ranges that have no UTC timestamp for the relevant boundary are kept (conservative). When a bound is a RangeBound::Slot, slot fields are used directly.