pub fn spawn_control_manager(
url: String,
api_key: String,
create: CreateBacktestSessionRequest,
cancel: CancellationToken,
) -> ControlHandleExpand description
Spawn a ControlManager task and return a handle.
The continues channel has a bounded capacity of 1: we only ever have one
Continue in flight, and backpressuring the driver is the correct behavior
if the connection is temporarily down.