pub struct CreateSession {
pub start_slot: u64,
pub end_slot: Option<u64>,
pub slot_count: Option<u64>,
pub signer_filter: BTreeSet<Address>,
pub preload_programs: BTreeSet<Address>,
pub preload_account_bundles: Vec<String>,
pub send_summary: bool,
pub parallel: bool,
pub disconnect_timeout_secs: Option<u16>,
}Expand description
Builder for CreateBacktestSession.
Set either end_slot or slot_count (not both). Use the helper methods to
add account filters or preload programs.
Fields
start_slot: u64end_slot: Option<u64>slot_count: Option<u64>signer_filter: BTreeSet<Address>preload_programs: BTreeSet<Address>preload_account_bundles: Vec<String>send_summary: boolWhen true, include a session summary with transaction statistics in the Completed response.
parallel: boolWhen true, ask manager to create all available sessions in the target epoch.
disconnect_timeout_secs: Option<u16>Implementations
Sourceimpl CreateSession
impl CreateSession
Sourcepub fn builder() -> CreateSessionBuilder
pub fn builder() -> CreateSessionBuilder
Create an instance of CreateSession using the builder syntax
Sourceimpl CreateSession
impl CreateSession
Sourcepub fn add_signer_filter(self, address: Address) -> Self
pub fn add_signer_filter(self, address: Address) -> Self
Add an account to the signer filter.
Sourcepub fn add_preload_program(self, address: Address) -> Self
pub fn add_preload_program(self, address: Address) -> Self
Add a program to preload before the first continue.
Sourcepub fn into_params(self) -> Result<CreateSessionParams, BacktestClientError>
pub fn into_params(self) -> Result<CreateSessionParams, BacktestClientError>
Convert the builder into API parameters, validating slot options.
Sourcepub fn into_request(
self,
) -> Result<CreateBacktestSessionRequest, BacktestClientError>
pub fn into_request( self, ) -> Result<CreateBacktestSessionRequest, BacktestClientError>
Convert the builder into versioned create request payload.